# CLI Reference

This document describes all command-line options and usage patterns.

## __init__

## cache_handlers

## cache_handlers_enhanced

### Available Options

- `--total_requests` (int):
- `--cache_hits` (int):
- `--cache_misses` (int):
- `--hit_rate_percent` (float):
- `--avg_response_time_ms` (float):
- `--cache_size_mb` (float):
- `--entries_count` (int):
- `--oldest_entry_age_hours` (float):
- `--most_accessed_keys` (list\[tuple[(str, int)]\]):
- `--least_accessed_keys` (list\[tuple[(str, int)]\]):
- `--cache_efficiency_score` (float):
- `--type` (str):
- `--priority` (str):
- `--description` (str):
- `--estimated_benefit` (str):
- `--action_required` (str):

## handlers

## interactive

## options

### Available Options

- `--commit` (bool):
- `--interactive` (bool):
- `--no_config_updates` (bool):
- `--update_precommit` (bool):
- `--publish` (BumpOption | None):
- `--bump` (BumpOption | None):
- `--verbose` (bool):
- `--debug` (bool):
- `--clean` (bool):
- `--test` (bool):
- `--benchmark` (bool):
- `--test_workers` (int):
- `--test_timeout` (int):
- `--all` (BumpOption | None):
- `--ai_agent` (bool):
- `--start_mcp_server` (bool):
- `--stop_mcp_server` (bool):
- `--restart_mcp_server` (bool):
- `--create_pr` (bool):
- `--skip_hooks` (bool):
- `--fast` (bool):
- `--comp` (bool):
- `--async_mode` (bool):
- `--experimental_hooks` (bool):
- `--enable_pyrefly` (bool):
- `--enable_ty` (bool):
- `--cleanup` (t.Any | None):
- `--no_git_tags` (bool):
- `--skip_version_check` (bool):
- `--cleanup_pypi` (bool):
- `--keep_releases` (int):
- `--track_progress` (bool):
- `--orchestrated` (bool):
- `--boost_coverage` (bool):
- `--coverage` (bool):
- `--orchestration_strategy` (str):
- `--orchestration_progress` (str):
- `--orchestration_ai_mode` (str):
- `--monitor` (bool):
- `--enhanced_monitor` (bool):
- `--watchdog` (bool):
- `--start_websocket_server` (bool):
- `--stop_websocket_server` (bool):
- `--restart_websocket_server` (bool):
- `--websocket_port` (int | None):
- `--dev` (bool):
- `--dashboard` (bool):
- `--max_iterations` (int):
- `--enterprise_batch` (str | None):
- `--monitor_dashboard` (str | None):
- `--coverage_status` (bool):
- `--coverage_goal` (float | None):
- `--no_coverage_ratchet` (bool):
- `--skip_config_merge` (bool):
- `--disable_global_locks` (bool):
- `--global_lock_timeout` (int):
- `--global_lock_cleanup` (bool):
- `--global_lock_dir` (str | None):
- `--quick` (bool):
- `--thorough` (bool):
- `--clear_cache` (bool):
- `--cache_stats` (bool):
- `--strip_code` (bool | None):
- `--run_tests` (bool | None):
- `--ai_fix` (bool | None):
- `--full_release` (BumpOption | None):
- `--show_progress` (bool | None):
- `--advanced_monitor` (bool | None):
- `--coverage_report` (bool | None):
- `--clean_releases` (bool | None):

## utils
